FaceDetectorView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FaceDetectorView
Constructors
-
FaceDetectorView({Key? key, required void onRulesetCompleted(Rulesets ruleset)?, required Widget onValidationDone(CameraController? controller), List<
Rulesets> ruleset = const [Rulesets.smiling, Rulesets.blink, Rulesets.toRight, Rulesets.toLeft, Rulesets.tiltUp, Rulesets.tiltDown], required Widget child({required int countdown, required bool hasFace, required Rulesets state}), Color progressColor = Colors.green, Color activeProgressColor = Colors.red, int totalDots = 60, double dotRadius = 3, dynamic onSuccessValidation(bool validated)?, Color? backgroundColor = Colors.white, EdgeInsetsGeometry? contextPadding, Size cameraSize = const Size(200, 200), int pauseDurationInSeconds = 5}) -
const
Properties
- activeProgressColor → Color
-
final
- backgroundColor → Color?
-
final
- cameraSize → Size
-
final
- child → Widget Function({required int countdown, required bool hasFace, required Rulesets state})
-
final
- contextPadding → EdgeInsetsGeometry?
-
final
- dotRadius → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onRulesetCompleted → void Function(Rulesets ruleset)?
-
final
- onSuccessValidation → dynamic Function(bool validated)?
-
final
- onValidationDone → Widget Function(CameraController? controller)
-
final
- pauseDurationInSeconds → int
-
final
- progressColor → Color
-
final
-
ruleset
→ List<
Rulesets> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalDots → int
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FaceDetectorView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited